@@ -14,13 +14,13 @@ class StashGUI:
 		print('Warning: Config file not found or empty. This is required to use Stash.')
 		print(' ')
 		print('Instructions on creating a config file:')
-		print('1) Create your .config based off of .config-template')
+		print('1) Create your .config based off of the config-example.txt file.')
 		print('2) Place your .config file into {}'.format(self.configparser.rootpath))
 		print('3) [Optional] Encrypt your .config file with this app (this will create .config-c)')
 		print('4) [Optional] Delete your original .config file once .config-c is created')
 		print(' ')
-		print('See .config-template file as an example, located in:')
-		print(self.configparser.rootpath)
+		print('See config-template.txt file as an example, located here:')
+		print('https://github.com/MysticTechnology/ScramblerApp/tree/main/config')
 		print(' ')
 		print('Press any key to exit.')
 		input(); cmd.clear(); return
